==> solid-5.5.0.tar.xz: solid-5.5.0/src/solid/devices/backends/fakehw/fakeprocessor.h <==
/*
    Copyright 2006 Michaël Larouche <michael.larouche@kdemail.net>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef SOLID_BACKENDS_FAKEHW_FAKEPROCESSOR_H
#define SOLID_BACKENDS_FAKEHW_FAKEPROCESSOR_H

#include "fakedeviceinterface.h"
#include <solid/devices/ifaces/processor.h>

namespace Solid
{
namespace Backends
{
namespace Fake
{
class FakeProcessor : public FakeDeviceInterface, public Solid::Ifaces::Processor
{
    Q_OBJECT
    Q_INTERFACES(Solid::Ifaces::Processor)

public:
    explicit FakeProcessor(FakeDevice *device);
    ~FakeProcessor();

public Q_SLOTS:
    virtual int number() const;
    virtual int maxSpeed() const;
    virtual bool canChangeFrequency() const;
    virtual Solid::Processor::InstructionSets instructionSets() const;
};
}
}
}

#endif // SOLID_BACKENDS_FAKEHW_FAKEPROCESSOR_H

==> solid-5.10.0.tar.xz: solid-5.10.0/src/solid/devices/backends/fakehw/fakeprocessor.h <==
/*
    Copyright 2006 Michaël Larouche <michael.larouche@kdemail.net>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef SOLID_BACKENDS_FAKEHW_FAKEPROCESSOR_H
#define SOLID_BACKENDS_FAKEHW_FAKEPROCESSOR_H

#include "fakedeviceinterface.h"
#include <solid/devices/ifaces/processor.h>

namespace Solid
{
namespace Backends
{
namespace Fake
{
class FakeProcessor : public FakeDeviceInterface, public Solid::Ifaces::Processor
{
    Q_OBJECT
    Q_INTERFACES(Solid::Ifaces::Processor)

public:
    explicit FakeProcessor(FakeDevice *device);
    ~FakeProcessor();

public Q_SLOTS:
    int number() const Q_DECL_OVERRIDE;
    int maxSpeed() const Q_DECL_OVERRIDE;
    bool canChangeFrequency() const Q_DECL_OVERRIDE;
    Solid::Processor::InstructionSets instructionSets() const Q_DECL_OVERRIDE;
};
}
}
}

#endif // SOLID_BACKENDS_FAKEHW_FAKEPROCESSOR_H
